@@ -23,11 +23,11 @@
 
 #include <powerdevilbackendinterface.h>
 
-#include <QtDBus/QDBusConnection>
-#include <QtDBus/QDBusInterface>
+#include <QDBusConnection>
+#include <QDBusInterface>
 
-#include <solid/devicenotifier.h>
-#include <solid/device.h>
+#include <Solid/Device>
+#include <Solid/DeviceNotifier>
 
 namespace Solid {
 class Device;
@@ -45,11 +45,11 @@ public:
     virtual void init();
     static bool isAvailable();
 
-    virtual int brightnessValue(BrightnessControlType type = Screen) const;
-    virtual int brightnessValueMax(BrightnessControlType type = Screen) const;
+    virtual int brightness(BrightnessControlType type = Screen) const;
+    virtual int brightnessMax(BrightnessControlType type = Screen) const;
 
     virtual int brightnessKeyPressed(PowerDevil::BrightnessLogic::BrightnessKeyType type, BrightnessControlType controlType = Screen);
-    virtual bool setBrightnessValue(int brightnessValue, PowerDevil::BackendInterface::BrightnessControlType type = Screen);
+    virtual void setBrightness(int value, PowerDevil::BackendInterface::BrightnessControlType type = Screen);
     virtual KJob* suspend(PowerDevil::BackendInterface::SuspendMethod method);
 
 private:
