@@ -39,6 +39,7 @@
 #define UPOWER_IFACE_DEVICE "org.freedesktop.UPower.Device"
 
 #define LOGIN1_SERVICE "org.freedesktop.login1"
+#define CONSOLEKIT2_SERVICE "org.freedesktop.ConsoleKit"
 
 class UdevHelper;
 class XRandRXCBHelper;
@@ -64,6 +65,9 @@ public:
     virtual void setBrightness(int value, PowerDevil::BackendInterface::BrightnessControlType type = Screen);
     virtual KJob* suspend(PowerDevil::BackendInterface::SuspendMethod method);
 
+Q_SIGNALS:
+    void brightnessSupportQueried(bool available);
+
 private:
     void enumerateDevices();
     void addDevice(const QString &);
@@ -86,6 +90,7 @@ private slots:
 
 private:
     void animationValueChanged(const QVariant &value);
+    void initWithBrightness(bool brightnessSupport);
 
     // upower devices
     QMap<QString, OrgFreedesktopUPowerDeviceInterface *> m_devices;
