@@ -54,7 +54,7 @@ namespace PowerDevil
 
 Core::Core(QObject* parent)
     : QObject(parent)
-    , m_backend(0)
+    , m_backend(nullptr)
     , m_notificationsWatcher(nullptr)
     , m_criticalBatteryTimer(new QTimer(this))
     , m_activityConsumer(new KActivities::Consumer(this))
@@ -129,6 +129,12 @@ void Core::onBackendReady()
 
     // Set up the policy agent
     PowerDevil::PolicyAgent::instance()->init();
+    // When inhibitions change, simulate user activity, see Bug 315438
+    connect(PowerDevil::PolicyAgent::instance(), &PowerDevil::PolicyAgent::unavailablePoliciesChanged, this,
+            [](PowerDevil::PolicyAgent::RequiredPolicies newPolicies) {
+        Q_UNUSED(newPolicies);
+        KIdleTime::instance()->simulateUserActivity();
+    });
 
     // Initialize the action pool, which will also load the needed startup actions.
     PowerDevil::ActionPool::instance()->init(this);
@@ -168,32 +174,6 @@ bool Core::isActionSupported(const QString& actionName)
     }
 }
 
-QString Core::checkBatteryStatus(bool notify)
-{
-    QString lastMessage;
-    // Any batteries below 50% of capacity?
-    for (QHash< QString, uint >::const_iterator i = m_backend->capacities().constBegin();
-         i != m_backend->capacities().constEnd(); ++i) {
-        if (i.value() < 50) {
-            // Notify, we have a broken battery.
-            if (m_loadedBatteriesUdi.size() == 1) {
-                lastMessage = i18n("Your battery capacity is %1%. This means your battery is broken and "
-                                   "needs a replacement. Please contact your hardware vendor for more details.",
-                                   i.value());
-            } else {
-                lastMessage = i18n("One of your batteries (ID %2) has a capacity of %1%. This means it is broken "
-                                   "and needs a replacement. Please contact your hardware vendor for more details.",
-                                   i.value(), i.key());
-            }
-            if (notify) {
-                emitRichNotification("brokenbattery", i18n("Broken Battery"), lastMessage);
-            }
-        }
-    }
-
-    return lastMessage;
-}
-
 void Core::refreshStatus()
 {
     /* The configuration could have changed if this function was called, so
@@ -500,27 +480,7 @@ bool Core::emitBatteryChargePercentNotification(int currentPercent, int previous
 
     if (currentPercent <= PowerDevilSettings::batteryCriticalLevel() &&
         previousPercent > PowerDevilSettings::batteryCriticalLevel()) {
-        switch (PowerDevilSettings::batteryCriticalAction()) {
-        case PowerDevil::BundledActions::SuspendSession::ShutdownMode:
-            emitRichNotification("criticalbattery", i18n("Battery Critical (%1% Remaining)", currentPercent),
-                             i18n("Your battery level is critical, the computer will be halted in 60 seconds."));
-            m_criticalBatteryTimer->start();
-            break;
-        case PowerDevil::BundledActions::SuspendSession::ToDiskMode:
-            emitRichNotification("criticalbattery", i18n("Battery Critical (%1% Remaining)", currentPercent),
-                             i18n("Your battery level is critical, the computer will be hibernated in 60 seconds."));
-            m_criticalBatteryTimer->start();
-            break;
-        case PowerDevil::BundledActions::SuspendSession::ToRamMode:
-            emitRichNotification("criticalbattery", i18n("Battery Critical (%1% Remaining)", currentPercent),
-                             i18n("Your battery level is critical, the computer will be suspended in 60 seconds."));
-            m_criticalBatteryTimer->start();
-            break;
-        default:
-            emitRichNotification("criticalbattery", i18n("Battery Critical (%1% Remaining)", currentPercent),
-                                 i18n("Your battery level is critical, save your work as soon as possible."));
-            break;
-        }
+        handleCriticalBattery(currentPercent);
         return true;
     } else if (currentPercent <= PowerDevilSettings::batteryLowLevel() &&
                previousPercent > PowerDevilSettings::batteryLowLevel()) {
@@ -531,6 +491,44 @@ bool Core::emitBatteryChargePercentNotification(int currentPercent, int previous
     return false;
 }
 
+void Core::handleCriticalBattery(int percent)
+{
+    // no parent, but it won't leak, since it will be closed both in case of timeout or direct action
+    m_criticalBatteryNotification = new KNotification("criticalbattery", KNotification::Persistent, nullptr);
+    m_criticalBatteryNotification->setComponentName(QStringLiteral("powerdevil"));
+    m_criticalBatteryNotification->setTitle(i18n("Battery Critical (%1% Remaining)", percent));
+
+    const QStringList actions = {i18nc("Cancel timeout that will automatically suspend system because of low battery", "Cancel")};
+
+    connect(m_criticalBatteryNotification.data(), &KNotification::action1Activated, this, [this] {
+        m_criticalBatteryTimer->stop();
+        m_criticalBatteryNotification->close();
+    });
+
+    switch (PowerDevilSettings::batteryCriticalAction()) {
+    case PowerDevil::BundledActions::SuspendSession::ShutdownMode:
+        m_criticalBatteryNotification->setText(i18n("Your battery level is critical, the computer will be halted in 60 seconds."));
+        m_criticalBatteryNotification->setActions(actions);
+        m_criticalBatteryTimer->start();
+        break;
+    case PowerDevil::BundledActions::SuspendSession::ToDiskMode:
+        m_criticalBatteryNotification->setText(i18n("Your battery level is critical, the computer will be hibernated in 60 seconds."));
+        m_criticalBatteryNotification->setActions(actions);
+        m_criticalBatteryTimer->start();
+        break;
+    case PowerDevil::BundledActions::SuspendSession::ToRamMode:
+        m_criticalBatteryNotification->setText(i18n("Your battery level is critical, the computer will be suspended in 60 seconds."));
+        m_criticalBatteryNotification->setActions(actions);
+        m_criticalBatteryTimer->start();
+        break;
+    default:
+        m_criticalBatteryNotification->setText(i18n("Your battery level is critical, save your work as soon as possible."));
+        // no timer, no actions
+        break;
+    }
+
+    m_criticalBatteryNotification->sendEvent();
+}
 
 void Core::onAcAdapterStateChanged(PowerDevil::BackendInterface::AcAdapterState state)
 {
@@ -610,6 +608,10 @@ void Core::onBatteryChargeStateChanged(int state, const QString &udi)
 
 void Core::onCriticalBatteryTimerExpired()
 {
+    if (m_criticalBatteryNotification) {
+        m_criticalBatteryNotification->close();
+    }
+
     // Do that only if we're not on AC
     if (m_backend->acAdapterState() == BackendInterface::Unplugged) {
         // We consider this as a very special button
@@ -706,9 +708,6 @@ void Core::onServiceRegistered(const QString &service)
         return;
     }
 
-    // Now emit all the notifications
-    checkBatteryStatus();
-
     // show warning about low batteries right on session startup, force it to show
     // by making sure the "old" percentage (that magic number) is always higher than the current one
     if (emitBatteryChargePercentNotification(currentChargePercent(), 1000)) {
